pub struct Filters {
pub statuses: Option<Vec<String>>,
pub priority: Option<u32>,
pub priority_lte: Option<u32>,
pub priority_gte: Option<u32>,
pub tags_any: Option<Vec<String>>,
pub tags_all: Option<Vec<String>>,
pub include_deleted: bool,
pub limit: Option<usize>,
pub offset: Option<usize>,
}Expand description
Common filter options for listing items
Fields
statuses: Option<Vec<String>>Filter by statuses (any match); None = no filter
priority: Option<u32>Filter by exact priority; None = no filter
priority_lte: Option<u32>Filter by priority less than or equal to this value; None = no filter
priority_gte: Option<u32>Filter by priority greater than or equal to this value; None = no filter
Filter by tags — item must have at least one of these tags; None = no filter
Filter by tags — item must have all of these tags; None = no filter
include_deleted: boolInclude soft-deleted items
limit: Option<usize>Limit number of results
offset: Option<usize>Offset for pagination
Implementations
Sourceimpl Filters
impl Filters
Sourcepub fn with_status(self, status: impl Into<String>) -> Self
pub fn with_status(self, status: impl Into<String>) -> Self
Filter by a single status (convenience wrapper for with_statuses)
Sourcepub fn with_statuses(self, statuses: Vec<String>) -> Self
pub fn with_statuses(self, statuses: Vec<String>) -> Self
Filter by a set of statuses (any match)
Sourcepub fn with_priority(self, priority: u32) -> Self
pub fn with_priority(self, priority: u32) -> Self
Filter by exact priority
Sourcepub fn with_priority_lte(self, priority: u32) -> Self
pub fn with_priority_lte(self, priority: u32) -> Self
Filter by priority less than or equal to this value
Sourcepub fn with_priority_gte(self, priority: u32) -> Self
pub fn with_priority_gte(self, priority: u32) -> Self
Filter by priority greater than or equal to this value
Filter to items that have at least one of the given tags
Filter to items that have all of the given tags
Sourcepub fn include_deleted(self) -> Self
pub fn include_deleted(self) -> Self
Include soft-deleted items
Sourcepub fn with_limit(self, limit: usize) -> Self
pub fn with_limit(self, limit: usize) -> Self
Limit results
Sourcepub fn with_offset(self, offset: usize) -> Self
pub fn with_offset(self, offset: usize) -> Self
Offset results for pagination